exceptiontools.MissingTempoError
================================

.. abjad-lineage:: abjad.tools.exceptiontools.MissingTempoError.MissingTempoError

.. autoclass:: abjad.tools.exceptiontools.MissingTempoError.MissingTempoError
   :noindex:

Special Methods
---------------

.. automethod:: abjad.tools.exceptiontools.MissingTempoError.MissingTempoError.__delattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingTempoError.MissingTempoError.__getitem__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingTempoError.MissingTempoError.__getslice__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingTempoError.MissingTempoError.__repr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingTempoError.MissingTempoError.__setattr__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingTempoError.MissingTempoError.__setstate__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingTempoError.MissingTempoError.__str__
   :noindex:

.. automethod:: abjad.tools.exceptiontools.MissingTempoError.MissingTempoError.__unicode__
   :noindex:
